(* $Id: boot_main.ml 708 2007-07-29 21:49:10Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

open Godi_types;;
open Godi_query;;
open Printf;;

(* Especially for Cygwin: Complain if PATH contains spaces *)
( let path_sep =
    match Sys.os_type with
	"Win32" -> ";"
      | _ -> ":" in
  let path_str = ( try Sys.getenv "PATH" with Not_found -> "" ) in
  let path = Str.split (Str.regexp path_sep) path_str in
  let newpath =
    List.filter
      (fun p ->
	 not(String.contains p ' ')
      )
      path
  in
  if newpath <> path then (
    eprintf "The PATH variable contains spaces. This is not supported by\n";
    eprintf "this program. The problematic PATH components are removed\n";
    eprintf "for the run time of this program. Beware that this might cause\n";
    eprintf "other problems.\n";
    flush stderr;
    Godi_exec.set_path (String.concat path_sep newpath)
  )
);;


(* Unset some findlib-related variables *)
( Godi_exec.set_variable "OCAMLFIND_DESTDIR" "";
  Godi_exec.set_variable "OCAMLFIND_METADIR" "";
  Godi_exec.set_variable "OCAMLPATH" "";
  Godi_exec.set_variable "OCAMLFIND_COMMANDS" "";
  Godi_exec.set_variable "OCAMLFIND_LDCONF" "";
);;

(* Announce special features *)
Godi_exec.set_variable "GODI_CONSOLE_SUPPORTS_CONFLICTS" "yes";;


( let enable_experimental =
    try Sys.getenv "GODI_EXP" <> "" with Not_found -> false in
  Godi_global.experimental_make := enable_experimental;

  if enable_experimental then (
    eprintf "Experimental mode is enabled. Not all functions will work\n";
    eprintf "as expected.\n";
    flush stderr;
  )
);;


try
  Godi_boot.is_bootconsole := true;
  Godi_wget_handler.init();
  if Array.length Sys.argv = 1 then
    print_endline "This is the GODI bootstrap console - no interactive mode available"
  else
    ( match Filename.basename Sys.argv.(0) with
      | "godi_make" ->
	  (* Catch this because it is error-prone... *)
	  failwith "GODI bootstrap console: self-invocation of godi_make not supported"
      | _ ->
	  Cmd.exec_cmd()
    );
  Godi_file.release_all_tmpdirs();
with
    Sys.Break ->
      Godi_file.release_all_tmpdirs();
      exit 10
  | Cmd.Exit_code n ->
      Godi_file.release_all_tmpdirs();
      exit n
  | Restart sh_cmd ->
      Godi_file.release_all_tmpdirs();
      Godi_file.execute ~setx:true sh_cmd
;;

